@@ -211,6 +211,10 @@ func main() {
 					Name:  "skip-diff-on-install",
 					Usage: "Skips running helm-diff on releases being newly installed on this apply. Useful when the release manifests are too huge to be reviewed, or it's too time-consuming to diff at all",
 				},
+				cli.StringSliceFlag{
+					Name:  "suppress",
+					Usage: "suppress specified Kubernetes objects in the output. Can be provided multiple times. For example: --suppress KeycloakClient --suppress VaultSecret",
+				},
 				cli.BoolFlag{
 					Name:  "suppress-secrets",
 					Usage: "suppress secrets in the output. highly recommended to specify on CI/CD use-cases",
@@ -282,6 +286,10 @@ func main() {
 					Name:  "include-crds",
 					Usage: "include CRDs in the templated output",
 				},
+				cli.BoolFlag{
+					Name:  "skip-tests",
+					Usage: "skip tests from templated output",
+				},
 				cli.BoolFlag{
 					Name:  "include-needs",
 					Usage: `automatically include releases from the target release's "needs" when --selector/-l flag is provided. Does nothing when when --selector/-l flag is not provided`,
@@ -513,6 +521,10 @@ func main() {
 					Name:  "include-tests",
 					Usage: "enable the diffing of the helm test hooks",
 				},
+				cli.StringSliceFlag{
+					Name:  "suppress",
+					Usage: "suppress specified Kubernetes objects in the diff output. Can be provided multiple times. For example: --suppress KeycloakClient --suppress VaultSecret",
+				},
 				cli.BoolFlag{
 					Name:  "suppress-secrets",
 					Usage: "suppress secrets in the diff output. highly recommended to specify on CI/CD use-cases",
@@ -678,6 +690,27 @@ func main() {
 				return a.ListReleases(c)
 			}),
 		},
+		{
+			Name:      "cache",
+			Usage:     "cache management",
+			ArgsUsage: "[command]",
+			Subcommands: []cli.Command{
+				{
+					Name:  "info",
+					Usage: "cache info",
+					Action: action(func(a *app.App, c configImpl) error {
+						return a.ShowCacheDir(c)
+					}),
+				},
+				{
+					Name:  "cleanup",
+					Usage: "clean up cache directory",
+					Action: action(func(a *app.App, c configImpl) error {
+						return a.CleanCacheDir(c)
+					}),
+				},
+			},
+		},
 		{
 			Name:      "version",
 			Usage:     "Show the version for Helmfile.",
@@ -704,7 +737,10 @@ type configImpl struct {
 
 func NewUrfaveCliConfigImpl(c *cli.Context) (configImpl, error) {
 	if c.NArg() > 0 {
-		cli.ShowAppHelp(c)
+		err := cli.ShowAppHelp(c)
+		if err != nil {
+			return configImpl{}, err
+		}
 		return configImpl{}, fmt.Errorf("err: extraneous arguments: %s", strings.Join(c.Args(), ", "))
 	}
 
@@ -819,6 +855,10 @@ func (c configImpl) IncludeTests() bool {
 	return c.c.Bool("include-tests")
 }
 
+func (c configImpl) Suppress() []string {
+	return c.c.StringSlice("suppress")
+}
+
 func (c configImpl) SuppressSecrets() bool {
 	return c.c.Bool("suppress-secrets")
 }
@@ -934,6 +974,10 @@ func (c configImpl) IncludeCRDs() bool {
 	return c.c.Bool("include-crds")
 }
 
+func (c configImpl) SkipTests() bool {
+	return c.c.Bool("skip-tests")
+}
+
 func (c configImpl) Logger() *zap.SugaredLogger {
 	return c.c.App.Metadata["logger"].(*zap.SugaredLogger)
 }
