@@ -90,27 +90,28 @@ func (st *HelmState) ExecuteTemplates() (*HelmState, error) {
 	vals := st.Values()
 
 	for i, rt := range st.Releases {
-		if rt.KubeContext == "" {
-			rt.KubeContext = r.HelmDefaults.KubeContext
+		release := rt
+		if release.KubeContext == "" {
+			release.KubeContext = r.HelmDefaults.KubeContext
 		}
-		if rt.Labels == nil {
-			rt.Labels = map[string]string{}
+		if release.Labels == nil {
+			release.Labels = map[string]string{}
 		}
 		for k, v := range st.CommonLabels {
-			rt.Labels[k] = v
+			release.Labels[k] = v
 		}
 		successFlag := false
-		for it, prev := 0, &rt; it < 6; it++ {
+		for it, prev := 0, &release; it < 6; it++ {
 			tmplData := st.createReleaseTemplateData(prev, vals)
 			renderer := tmpl.NewFileRenderer(st.readFile, st.basePath, tmplData)
-			r, err := rt.ExecuteTemplateExpressions(renderer)
+			r, err := release.ExecuteTemplateExpressions(renderer)
 			if err != nil {
-				return nil, fmt.Errorf("failed executing templates in release \"%s\".\"%s\": %v", st.FilePath, rt.Name, err)
+				return nil, fmt.Errorf("failed executing templates in release \"%s\".\"%s\": %v", st.FilePath, release.Name, err)
 			}
 			if reflect.DeepEqual(prev, r) {
 				successFlag = true
 				if err := updateBoolTemplatedValues(r); err != nil {
-					return nil, fmt.Errorf("failed executing templates in release \"%s\".\"%s\": %v", st.FilePath, rt.Name, err)
+					return nil, fmt.Errorf("failed executing templates in release \"%s\".\"%s\": %v", st.FilePath, release.Name, err)
 				}
 				st.Releases[i] = *r
 				break
@@ -118,7 +119,7 @@ func (st *HelmState) ExecuteTemplates() (*HelmState, error) {
 			prev = r
 		}
 		if !successFlag {
-			return nil, fmt.Errorf("failed executing templates in release \"%s\".\"%s\": %s", st.FilePath, rt.Name,
+			return nil, fmt.Errorf("failed executing templates in release \"%s\".\"%s\": %s", st.FilePath, release.Name,
 				"recursive references can't be resolved")
 		}
 	}
