@@ -2,9 +2,6 @@ package tmpl
 
 import (
 	"fmt"
-	"github.com/ghodss/yaml"
-	"github.com/roboll/helmfile/pkg/helmexec"
-	"golang.org/x/sync/errgroup"
 	"io"
 	"os"
 	"os/exec"
@@ -12,6 +9,10 @@ import (
 	"reflect"
 	"strings"
 	"text/template"
+
+	"github.com/ghodss/yaml"
+	"github.com/roboll/helmfile/pkg/helmexec"
+	"golang.org/x/sync/errgroup"
 )
 
 type Values = map[string]interface{}
@@ -20,7 +21,7 @@ func (c *Context) createFuncMap() template.FuncMap {
 	funcMap := template.FuncMap{
 		"exec":             c.Exec,
 		"readFile":         c.ReadFile,
-		"readDir":          ReadDir,
+		"readDir":          c.ReadDir,
 		"toYaml":           ToYaml,
 		"fromYaml":         FromYaml,
 		"setValueAtPath":   SetValueAtPath,
@@ -55,7 +56,7 @@ func (c *Context) Exec(command string, args []interface{}, inputs ...string) (st
 	for i, a := range args {
 		switch a.(type) {
 		case string:
-			strArgs[i] = a.(string)
+			strArgs[i] = fmt.Sprintf("%v", a)
 		default:
 			return "", fmt.Errorf("unexpected type of arg \"%s\" in args %v at index %d", reflect.TypeOf(a), args, i)
 		}
@@ -131,11 +132,19 @@ func (c *Context) ReadFile(filename string) (string, error) {
 	return string(bytes), nil
 }
 
-func ReadDir(path string) ([]string, error) {
-	entries, err := os.ReadDir(path)
-	if err != nil {
-		return nil, err
+func (c *Context) ReadDir(path string) ([]string, error) {
+	var contextPath string
+	if filepath.IsAbs(path) {
+		contextPath = path
+	} else {
+		contextPath = filepath.Join(c.basePath, path)
 	}
+
+	entries, err := os.ReadDir(contextPath)
+	if err != nil {
+		return nil, fmt.Errorf("ReadDir %q: %w", contextPath, err)
+	}
+
 	var filenames []string
 	for _, entry := range entries {
 		if entry.IsDir() {
@@ -143,6 +152,7 @@ func ReadDir(path string) ([]string, error) {
 		}
 		filenames = append(filenames, filepath.Join(path, entry.Name()))
 	}
+
 	return filenames, nil
 }
 
